@@ -10,7 +10,7 @@ LInormVar = function(x, k, conf.level=0.95)
   if (!missing(k)) {
     logk = log(k)
   } else {
-    logk = n0/2*log(1 + qf(conf.level, 1, n0 - 2)/(n0 - 2)) # two parameters with one nuisance (mean)
+    logk = n0/2*log(1 + qf(conf.level, 1, n0 - 1.2)/(n0 - 1.2)) # 1.2 is empirical
     logk = min(logk, log(2/(1 - conf.level)))
   }
 
