@@ -10,7 +10,7 @@ LIvtest = function(s1, n1, s2, n2, k, conf.level=0.95)
     logk = log(k)
     conf.level = pf((n - 1)*(k^(2/n) - 1), 1, n - 1)
   } else {
-    logk = n/2*log(1 + qf(conf.level, 1, n - 2)/(n - 2)) # two parameters
+    logk = n/2*log(1 + qf(conf.level, 1, n - 2.4)/(n - 2.4)) # empirical for two parameters
     logk = min(logk, log(2/(1 - conf.level)))
   }
 
